pub struct EnginePoolConfig {
pub max_size: usize,
pub min_size: usize,
pub ttl: Duration,
pub health_check_interval: Duration,
pub warmup_enabled: bool,
pub warmup_size: usize,
}Fields
max_size: usizeMaximum number of engines to keep in the pool
min_size: usizeMinimum number of engines to keep in the pool
ttl: DurationTime-to-live for engines in the pool
health_check_interval: DurationHealth check interval
warmup_enabled: boolwarmup_size: usizeTrait Implementations
Sourceimpl Clone for EnginePoolConfig
impl Clone for EnginePoolConfig
Sourcefn clone(&self) -> EnginePoolConfig
fn clone(&self) -> EnginePoolConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnginePoolConfig
impl Debug for EnginePoolConfig
Sourceimpl Default for EnginePoolConfig
impl Default for EnginePoolConfig
Sourceimpl<'de> Deserialize<'de> for EnginePoolConfig
impl<'de> Deserialize<'de> for EnginePoolConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more